use crate::random_names::get_name;
use crate::state::{Mailbox, State};
use rouille::{post_input, router, try_or_400, Request, Response};

pub fn http_handler(request: &Request, state: &State) -> Response {
    router!(request,
        (GET) (/) => {
            rouille::Response::text("hello world")
        },

        (GET) (/ffff) => {
            rouille::Response::redirect_302("/ffff/")
        },

        (GET) (/ffff/) => {
            rouille::Response::html("
                <h1>email stuff</h1>
                <form method='POST'>
                  <select name='domain'>
                    <option value='test.m5w.de'>test.m5w.de</option>
                  </select>
                  <input type='submit'>
                </form>
            ")
        },

        (POST) (/ffff/) => {
            let data = try_or_400!(post_input!(request, {
                domain: String
        }));

            let email = format!("{}@{}", get_name().to_lowercase(), data.domain);

            println!("{}", email);

            state.lock().unwrap().insert(email.clone(), Mailbox::new(email.clone()));

            rouille::Response::redirect_301(format!("{}/", email))
        },

        (GET) (/ffff/{email: String}/) => {
            println!("{}", email);

            if let Some(mailbox) = state.lock().unwrap().get(&email) {
                let body: &Vec<String> = &mailbox.messages.iter().enumerate().map(|(i, msg)| {
                     format!(
                         "<h3>\"{}\" from {}</h3><br><iframe src=\"{}\" sandbox csp=\"default-src 'none'; image-src data:\"></iframe><br>",
                          escape(&msg.subject),
                          escape(&msg.sender),
                          i
                     )
                }).collect();

                rouille::Response::html(format!(
                    "<h1>Mailbox: {}</h1>{}<small>okay bye</small>",
                    escape(&mailbox.email),
                    body.join("")
                ))
            } else {
                rouille::Response::text("Mailbox not found")
            }
        },

        (GET) (/ffff/{email: String}/{msg: usize}) => {
            if let Some(mailbox) = state.lock().unwrap().get(&email) {
                if let Some(mail) = mailbox.messages.get(msg) {
                    return rouille::Response::html(&mail.body)
                }
            }

            rouille::Response::text("Message not found")
        },

        _ => rouille::Response::empty_404()
    )
}

fn escape(data: &str) -> String {
    data.replace('>', "&gt;")
        .replace('<', "&lt;")
        .replace('\"', "&quot;")
        .replace('\'', "&apos;")
}
