use chrono::{DateTime, Utc};
use std::collections::HashMap;
use std::sync::{Arc, Mutex};

pub type State = Arc<Mutex<HashMap<String, Mailbox>>>;

pub fn fresh_state() -> State {
    Arc::new(Mutex::new(HashMap::new()))
}

pub struct Mailbox {
    pub email: String,
    pub messages: Vec<Message>,
    pub created_at: DateTime<Utc>,
}

#[derive(Clone)]
pub struct Message {
    pub sender: String,
    pub recipients: Vec<String>,
    pub subject: String,
    pub body: String,
}

impl Mailbox {
    pub fn new(email: String) -> Self {
        Self {
            email,
            messages: Vec::new(),
            created_at: Utc::now(),
        }
    }
}
